@@ -4,7 +4,7 @@ import sqlalchemy.exc
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.orm.scoping import scoped_session
 
-from functions import first, identity, last, merge, rest
+from functions import first, format, identity, last, merge, rest
 
 
 INSERT_TEMPLATES = {
